==> open-xchange-util-custom_1.2.1.orig.tar.bz2: open-xchange-util-custom-1.2.1/com.openexchange.util.custom/src/com/openexchange/util/custom/config/ConfigTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.util.custom.config;

import java.util.HashSet;
import java.util.Set;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import com.openexchange.config.DefaultInterests;
import com.openexchange.config.Interests;

/**
 * Keeps track of configuration properties and files in order to generate
 * a list of {@link Interests}.
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.2.0
 */
@ParametersAreNonnullByDefault
public class ConfigTracker {
    private static final String[] STRING_ARRAY_MARKER = new String[0];
    private final Set<String> properties;
    private final Set<String> files;
    
    /**
     * Initializes a new {@link ConfigTracker} that will use the specified
     * {@link Set}s to collect property names and file names.
     * 
     * @param propertiesSet
     * @param filesSet
     */
    public ConfigTracker(final Set<String> propertiesSet, final Set<String> filesSet) {
        this.properties = propertiesSet;
        this.files = filesSet;
    }

    /**
     * Initializes a new {@link ConfigTracker} that will use the specified
     * {@link Set} to collect property names and its own {@link Set} for
     * file names.
     * 
     * @param propertiesSet
     * @deprecated use {@link ConfigTracker#ConfigTracker(Set, Set)} or {@link ConfigTracker#ConfigTracker()}
     */
    // for backwards compatibility
    @Deprecated
    public ConfigTracker(final Set<String> propertiesSet) {
        this.properties = propertiesSet;
        this.files = new HashSet<>();
    }
    public ConfigTracker() {
        this.properties = new HashSet<>();
        this.files = new HashSet<>();
    }
    public @Nullable Interests interests() {
        final DefaultInterests.Builder b = DefaultInterests.builder();
        b.propertiesOfInterest(properties.toArray(STRING_ARRAY_MARKER));
        b.configFileNames(files.toArray(STRING_ARRAY_MARKER));
        return b.build();
    }
    public ConfigTracker trackProperty(final String propertyName) {
        this.properties.add(propertyName);
        return this;
    }
    public ConfigTracker trackConfigFileName(final String filename) {
        this.files.add(filename);
        return this;
    }
}

==> open-xchange-util-custom_1.3.1.orig.tar.bz2: open-xchange-util-custom-1.3.1/com.openexchange.util.custom/src/com/openexchange/util/custom/config/ConfigTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.util.custom.config;

import java.util.HashSet;
import java.util.Set;
import com.openexchange.annotation.Nullable;
import com.openexchange.config.DefaultInterests;
import com.openexchange.config.Interests;

/**
 * Keeps track of configuration properties and files in order to generate
 * a list of {@link Interests}.
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.2.0
 */
public class ConfigTracker {
    private static final String[] STRING_ARRAY_MARKER = new String[0];
    private final Set<String> properties;
    private final Set<String> files;
    
    /**
     * Initializes a new {@link ConfigTracker} that will use the specified
     * {@link Set}s to collect property names and file names.
     * 
     * @param propertiesSet
     * @param filesSet
     */
    public ConfigTracker(final Set<String> propertiesSet, final Set<String> filesSet) {
        this.properties = propertiesSet;
        this.files = filesSet;
    }

    /**
     * Initializes a new {@link ConfigTracker} that will use the specified
     * {@link Set} to collect property names and its own {@link Set} for
     * file names.
     * 
     * @param propertiesSet
     * @deprecated use {@link ConfigTracker#ConfigTracker(Set, Set)} or {@link ConfigTracker#ConfigTracker()}
     */
    // for backwards compatibility
    @Deprecated
    public ConfigTracker(final Set<String> propertiesSet) {
        this.properties = propertiesSet;
        this.files = new HashSet<>();
    }
    public ConfigTracker() {
        this.properties = new HashSet<>();
        this.files = new HashSet<>();
    }
    public @Nullable Interests interests() {
        final DefaultInterests.Builder b = DefaultInterests.builder();
        b.propertiesOfInterest(properties.toArray(STRING_ARRAY_MARKER));
        b.configFileNames(files.toArray(STRING_ARRAY_MARKER));
        return b.build();
    }
    public ConfigTracker trackProperty(final String propertyName) {
        this.properties.add(propertyName);
        return this;
    }
    public ConfigTracker trackConfigFileName(final String filename) {
        this.files.add(filename);
        return this;
    }
}
